<?php
/**
 * @file
 * Administrative page callbacks for format_title module.
 */

/**
 * Form constructor for settings page.
 */
function format_title_settings() {
  $entities = format_title_get_entity_properties();
  $settings = variable_get('format_title_settings', array());

  if ( !empty($entities) ) {
    $table = array(
      'header' => array(
        'entity' => t('Entity'),
        'bundles' => t('Enabled bundles')
      )
    );

    foreach ( $entities as $entity => $properties ) {
      // Build list of enabled bundles
      $enabled_bundles = array();
      foreach ( $properties['bundles'] as $bundle => $bundle_properties ) {
        if ( !empty($settings[$entity][$bundle]) ) {
          $enabled_bundles[$bundle] = t($bundle_properties['label']);
        }
      }

      $enabled_bundles = empty($enabled_bundles) ? t('No bundles enabled') : implode(', ', $enabled_bundles);

      $table['rows'][] = array(
        'entity' => l(t($properties['name']), 'admin/config/content/format-title/' . $entity),
        'bundles' => $enabled_bundles
      );
    }

    $form['format_title_entities'] = array(
      '#markup' => theme('table', $table)
    );
  }

  $form['format_title_allowed_tags'] = array(
    '#type' => 'textfield',
    '#title' => t('Allowed HTML tags'),
    '#default_value' => variable_get('format_title_allowed_tags', '<em> <strong>')
  );

  return system_settings_form($form);
}

/**
 * Form constructor for entity-specific settings page.
 */
function format_title_entity_settings($form, &$form_state, $entity_type) {
  $settings = variable_get('format_title_settings', array());
  $settings = empty($settings[$entity_type]) ? array() : $settings[$entity_type];

  $entity = format_title_get_entity_properties($entity_type);
  $form_state['build_info']['entity'] = $entity;
  extract($entity);

  drupal_set_title(t('!entity Format Title settings', array('!entity' => t($name))));

  if ( !empty($bundles) ) {
    $form['warning'] = array(
      '#markup' => t('Please note that these settings affect only entity title fields set at the root of the form. Placing a title field within a field group will prevent Formatted Titles from working properly.')
    );

    $form['format_title_settings'] = array(
      '#type' => 'container',
      '#tree' => TRUE
    );

    $form['format_title_settings'][$entity_type] = array(
      '#type' => 'checkboxes',
      '#title' => t('Bundles'),
      '#description' => t('Choose which bundles will have a formatted title field.'),
      '#default_value' => $settings
    );

    foreach ( $bundles as $bundle_name => $bundle ) {
      $form['format_title_settings'][$entity_type]['#options'][$bundle_name] = t($bundle['label']);
    }

    $form['submit'] = array(
      '#type' => 'submit',
      '#value' => t('Save settings')
    );
  }
  else {
    $form['empty'] = array(
      '#markup' => t('There are no available bundles for the !entity entity.', array('!entity' => t($name)))
    );
  }

  return $form;
}

/**
 * Form submission handler for format_title_entity_settings().
 */
function format_title_entity_settings_submit($form, &$form_state) {
  $settings = variable_get('format_title_settings', array());
  $settings = array_merge($settings, $form_state['values']['format_title_settings']);
  variable_set('format_title_settings', $settings);
  drupal_set_message(t('Format Title settings for !entity have been saved.', array('!entity' => t($form_state['build_info']['entity']['name']))));
  $form_state['redirect'] = 'admin/config/content/format-title';
}